%Q5_Wonka_column
function Q5_Wonka_column
       
%Chocolate viscosity ratios (compared to water)
%(<40 for fountains, >120 for moulding)
CVR = [40, 60, 80, 100, 120, 140];

%Height of chocolate test column /m
D = 5/100;  

%

%Determine ball dynamics
for n=1:length(CVR)
    [choc(n).t,choc(n).T,choc(n).x,choc(n).v,...
        choc(n).vT,choc(n).Re,choc(n).rV,r] = ball_dynamics( CVR(n),D );
end

%Fontsize for plots
fsize = 18;  

%Plot drop distance vs time
set(gca,'fontsize',fsize,'nextplot','add'); grid on; box on;
plot_RGB = rand(length(CVR),3);
for n=1:length(CVR)
    plot( choc(n).t,choc(n).x*100,'color',plot_RGB(n,:) );
    legend_str{n} = ['CVR=',num2str(CVR(n)),...
        ', t=',num2str(choc(n).t(end),3),'s'];
end
ylim([0,D*100])
xlabel( 'time t/s','fontsize',fsize )
ylabel( 'x /cm','fontsize',fsize );
legend( legend_str, 'fontsize',fsize,'location','southeast' );
title( [num2str(D*100),'cm chocolate column drop. r=',num2str(r*100,3),'cm.'],'fontsize',fsize )
print( gcf,'chocolate x vs t.png','-dpng','-r300' );
clf;

%Plot velocity vs time
set(gca,'fontsize',fsize,'nextplot','add'); grid on; box on;
for n=1:length(CVR)
    plot( choc(n).t,choc(n).v*100,'color',plot_RGB(n,:) );
end
xlabel( 'time t/s','fontsize',fsize )
ylabel( 'v /cms^{-1}','fontsize',fsize )
legend( legend_str, 'fontsize',fsize );
title( [num2str(D*100),'cm chocolate column drop. r=',num2str(r*100,3),'cm.'],'fontsize',fsize )
print( gcf,'chocolate v vs t.png','-dpng','-r300' );
close(gcf);

%%

%Dynamics of viscous ball drop in chocolate
function [t,T,x,v,vT,Re,rV,r] = ball_dynamics(CVR,D)

g = 9.81;           %Gravitational field strength /Nkg^-1
rho_c = 1325;       %Density of molten chocolate /kgm^-3
rho = 8050;         %Density of steel ball /kgm^-3
rho = 1500;         %Density of Everlasting Gobstopper /kgm^-3
mu_w = 1.0e-3;      %Viscosity of water /Pa*s
mu = CVR*mu_w;      %Viscosity of chocolate /Pa*s
m = 1e-4;           %Mass of sphere
dt = 0.001;         %Timestep /s
cD = 0.47;          %Drag coefficient for a sphere

r = ( 3*m/(4*pi*rho) )^(1/3);    %Sphere radius /m
tau = m/(6*pi*mu*r);             %Time constant /s
X = g*(1 - rho_c/rho)*(tau^2);   %Distance constant /m

%Terminal velocity
vT = (2/9)*g*(r^2)*(rho-rho_c)/mu;   

%Maximum Reynold's number
Re = rho_c*r*vT/mu;

%Upper limit for ball radius for viscous forces to dominate over
%hydrodynamic ones
rV = ( 54*(mu^2)/( cD*rho_c*g*(rho-rho_c) ) )^(1/3);

x=0; v = 0; t = 0;
while x(end)<D
    t = [t,t(end)+dt];
    %Drop distance /m
    x = [x,X*( t(end)/tau + exp(-t(end)/tau) -1 )];
    %Velocity (ms^-1)
    v = [v,g*(1-rho_c/rho)*tau*( 1-exp(-t(end)/tau) )];
end
T = t(end);

%End of code
