%Q6_Skyfall
function Q6_Skyfall

g = 9.81;       %Gravitational field strength /Nkg^-1
A = 4.0;        %Parachute area /m^2
m = 80;         %James Bond's mass /kg   
H = 10400;      %Air density model scale height /m
dt = 0.01;      %Timestep /s
rho0 = 1.225;   %Ground level air density /kgm^-3
h0 = 3658;      %Initial altitude /m
fsize = 18;     %Fontsize for graphs

%Terminal speed /ms^-1
vT = sqrt( 2*m*g/(A*rho0) );

%Compute dynamics using VDAV method
t = 0; h = h0; v = 0;
while h(end) > 0
    alpha = g*( 1 - ( ( v(end)/vT)^2 )*exp( -h(end)/H ) ) ;
    t = [t,t(end) + dt];
    h = [h,h(end)-v(end)*dt-0.5*alpha*(dt^2) ];
    beta = g*( 1 - ( ( v(end)/vT)^2 )*exp( -h(end)/H ) ) ;
    v = [v,v(end)+0.5*(alpha+beta)*dt ];
end

%Plot altitude vs time
plot(t,h); set(gca,'fontsize',fsize); grid on; box on; ylim([0,h0]);
xlabel( 'time t/s','fontsize',fsize );
ylabel( 'Altitude h /m','fontsize',fsize );
title(['Fall from ',num2str(h0),'m in ',...
    num2str(t(end),3),'s. v_T=',num2str(vT,3),'m/s.'],'fontsize',fsize );
print( gcf,'Skyfall x vs t.png','-dpng','-r300' );
clf;

%Plot velocity vs time
plot(t,v); set(gca,'fontsize',fsize); grid on; box on;
xlabel( 'time t/s','fontsize',fsize );
ylabel( 'velocity v /ms^{-1}','fontsize',fsize );
title(['Fall from ',num2str(h0),'m in ',...
    num2str(t(end),3),'s. v_T=',num2str(vT,3),'m/s.'],'fontsize',fsize );
print( gcf,'Skyfall v vs t.png','-dpng','-r300' );
close(gcf);

%End of code

